%global major           2
%define libname         %mklibname %{name} %{major}
%define devname         %mklibname %{name} -d

%global gettext_package FontForge

Name:           fontforge
Version:        20201107
Release:        %mkrel 1
Summary:        Font Editor for PostScript, TrueType, OpenType and various fonts
License:        GPLv3+
Group:          Publishing
URL:            http://fontforge.github.io
Source0:        https://github.com/fontforge/fontforge/archive/%{version}/%{name}-%{version}.tar.gz
# Remove tests that requires Internet access
Patch0:         fontforge-20201107-remove-internet-tests.patch

BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  gettext
BuildRequires:  giflib-devel
BuildRequires:  git
BuildRequires:  libltdl-devel
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gdk-3.0)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libspiro)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libuninameslist)
BuildRequires:  pkgconfig(libwoff2enc)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(readline)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xproto)
BuildRequires:  pkgconfig(xt)
BuildRequires:  python3-sphinx
BuildRequires:  shared-mime-info
BuildRequires:  uthash-devel

Provides:       bundled(gnulib)

%description
FontForge is a font editor for outline and bitmap fonts. It supports a range of
font formats, including PostScript (ASCII and binary Type 1, some Type 3 and
Type 0), TrueType, OpenType (Type2) and CID-keyed fonts.

%package -n     %{devname}
Summary:        Development tools for fontforge
Requires:       %{name} = %{version}-%{release}
Requires:       pkgconfig

%description -n %{devname}
This package includes the libraries and header files you will need
to compile applications against fontforge.

 
	
%package doc
Summary: Documentation files for %{name}
BuildArch: noarch

%description doc
This package contains documentation files for %{name}

%prep
%autosetup -p1

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%cmake -DCMAKE_BUILD_TYPE=Release -DENABLE_WOFF2=ON
%cmake_build

%install
%cmake_install

# remove unneeded .la and .a files
find %{buildroot} -name '*.la' -delete
find %{buildroot} -name '*.a' -delete

# Find translations
%find_lang %{gettext_package}

%files -f %{gettext_package}.lang
%license LICENSE
%{_bindir}/font*
%{_bindir}/sfddiff
%{_datadir}/%{name}/
%{_datadir}/applications/org.%{name}.FontForge.desktop
%{_datadir}/metainfo/org.%{name}.FontForge.appdata.xml
%{_datadir}/mime/packages/%{name}.xml
%{_datadir}/pixmaps/org.%{name}.FontForge.*
%{_iconsdir}/hicolor/*/apps/org.%{name}.FontForge.*
%{_libdir}/lib*.so.*
%{_mandir}/man1/*.1*
%{python3_sitearch}/%{name}.so
%{python3_sitearch}/psMat.so

%files -n %{devname}
%{_libdir}/lib*.so

%files doc
%doc %{_pkgdocdir}


%changelog
* Wed Dec 30 2020 akien <akien> 20201107-1.mga8
+ Revision: 1665671
- Version 20201107

* Thu Oct 29 2020 joequant <joequant> 20200314-1.mga8
+ Revision: 1640508
- add sphinx
- update deps
- add cmake
- update to 20200314

* Wed Feb 19 2020 umeabot <umeabot> 20190801-6.mga8
+ Revision: 1543550
- Mageia 8 Mass Rebuild

* Tue Jan 21 2020 ns80 <ns80> 20190801-5.mga8
+ Revision: 1481901
- add upstream patch for  CVE-2020-5395 and CVE-2020-5496 (mga#26095)
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Jan 04 2020 tv <tv> 20190801-4.mga8
+ Revision: 1476443
- rebuild with new readline

* Tue Oct 29 2019 daviddavid <daviddavid> 20190801-3.mga8
+ Revision: 1456482
- rebuild for new libspiro 20190731

* Tue Sep 10 2019 wally <wally> 20190801-2.mga8
+ Revision: 1439407
- rebuild for python3.8

* Tue Aug 20 2019 daviddavid <daviddavid> 20190801-1.mga8
+ Revision: 1430519
- new version: 20190801

* Sun Apr 21 2019 akien <akien> 20190413-1.mga7
+ Revision: 1394570
- Version 20190413

* Tue Jan 08 2019 tv <tv> 20170731-8.mga7
+ Revision: 1352478
- rebuild with python 3.7

* Sun Sep 23 2018 umeabot <umeabot> 20170731-7.mga7
+ Revision: 1297739
- Mageia 7 Mass Rebuild

* Tue Jan 02 2018 wally <wally> 20170731-6.mga7
+ Revision: 1189426
- rebuild for new readline

* Sat Aug 05 2017 pterjan <pterjan> 20170731-5.mga7
+ Revision: 1135211
- Rebuild for python 3.6

* Mon Jul 31 2017 shlomif <shlomif> 20170731-4.mga7
+ Revision: 1133268
- New version 201707

* Fri Jun 30 2017 shlomif <shlomif> 20161012-4.mga6
+ Revision: 1108750
- Get rid of the autotrace dep, because we're deprecating autotrace.
  It is optional anyway.

* Sat Feb 04 2017 wally <wally> 20161012-3.mga6
+ Revision: 1084816
- drop requires that are already pulled via autoreqs

* Thu Feb 02 2017 daviddavid <daviddavid> 20161012-2.mga6
+ Revision: 1084613
- rebuild for new libuninameslist

* Sun Jan 29 2017 akien <akien> 20161012-1.mga6
+ Revision: 1084100
- Version 20161012 (partial sync with Fedora)
- Use python3 instead of python2

* Tue Sep 20 2016 ghibo <ghibo> 20160404-1.mga6
+ Revision: 1054583
- Fix permission of FontForgeSplash.png in docs
- New release 20160404

* Sun Jan 10 2016 daviddavid <daviddavid> 20150824-4.mga6
+ Revision: 921204
- rebuild for new giflib 5.1.2

* Tue Nov 24 2015 tv <tv> 20150824-3.mga6
+ Revision: 905703
- BR spiro-devel

* Mon Nov 23 2015 daviddavid <daviddavid> 20150824-2.mga6
+ Revision: 905283
- install all icons manually (workaround to fix build)
- remove invalid Requires on fontforge-doc
- fix Release tag
- add a mime-package file and an appdata file
+ tv <tv>
- further reduce diff with FC
- require autorace instead of fonttracer
- reduce diff with FC
- use bundled desktop entry
- kill BR on libx11-devel

* Wed Nov 18 2015 tv <tv> 20150824-1.20120731.10.mga6
+ Revision: 904091
- adjust file list + create devel pkg
- package libs

* Wed Nov 18 2015 tv <tv> 20150824-1.20120731.9.mga6
+ Revision: 904075
- BR libltdl-devel
- add more BRs
- BR git
- fix SOURCE1 URL for mgarepo sync
- new release

* Wed Oct 15 2014 umeabot <umeabot> 1.0-1.20120731.9.mga5
+ Revision: 741428
- Second Mageia 5 Mass Rebuild

* Fri Sep 26 2014 tv <tv> 1.0-1.20120731.8.mga5
+ Revision: 725052
- rebuild for bogus file deps

* Tue Sep 16 2014 umeabot <umeabot> 1.0-0.20120731.8.mga5
+ Revision: 679255
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 1.0-0.20120731.7.mga4
+ Revision: 526399
- Mageia 4 Mass Rebuild

* Tue Jun 04 2013 fwang <fwang> 1.0-0.20120731.6.mga4
+ Revision: 436903
- we are now providing libpng16

* Mon Jun 03 2013 tv <tv> 1.0-0.20120731.5.mga4
+ Revision: 436312
- rebuild for new libpng

* Mon Jun 03 2013 fwang <fwang> 1.0-0.20120731.4.mga4
+ Revision: 435854
- rebuild for new libpng

* Fri Jan 11 2013 umeabot <umeabot> 1.0-0.20120731.3.mga3
+ Revision: 350654
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Oct 08 2012 tv <tv> 1.0-0.20120731.2.mga3
+ Revision: 303409
- BR x11-devel
- add patch from opensuse not to look for libpng.so.2
- requires libpng

* Tue Sep 11 2012 shlomif <shlomif> 1.0-0.20120731.1.mga3
+ Revision: 292435
- New version - 20120731-b

* Thu May 10 2012 doktor5000 <doktor5000> 1.0-0.20110222.3.mga2
+ Revision: 235150
- remove unneeded explicit Require on mfwin/texlive (mga#5812)

* Thu Oct 27 2011 doktor5000 <doktor5000> 1.0-0.20110222.2.mga2
+ Revision: 158591
- updated fontforge-tutorial.pdf
- updated cidmaps tarball, use upstream tarball, don't recompress
- added back local-helpdir.patch and properly renamed it
- removed unrecognized configure options
- use %%make macro
- removed deprecated %%clean section

* Sun Jun 19 2011 spuhler <spuhler> 1.0-0.20110222.1.mga2
+ Revision: 109560
- upgraded version to	20110222
  upgraded docversion	20110221
  removed Patch1: fontforge-%%{version}-local-helpdir.patch

* Tue Apr 26 2011 wally <wally> 1.0-0.20090923.5.mga1
+ Revision: 91662
- fix desktop file (mga#954)
- drop buildroot definition

* Fri Mar 04 2011 boklm <boklm> 1.0-0.20090923.4.mga1
+ Revision: 64137
- require mfwin instead of tetex-mfwin

* Mon Jan 17 2011 pterjan <pterjan> 1.0-0.20090923.3.mga1
+ Revision: 21122
- Drop obsolete scriptlets
- imported package fontforge

